From 96e67451c9569c6c93b4ab270d8f0e80580d8d14 Mon Sep 17 00:00:00 2001
From: Brownard <brownard>
Date: Mon, 30 Mar 2015 10:56:23 +0100
Subject: [PATCH] Improve movie name and year parsing

Replace '.' and '_' in paths with spaces
Don't require year to be surrounded with brackets
---
 .../OnlineLibraries/TheMovieDB/NamePreprocessor.cs    | 19 +++++++++++++++++--
 1 file changed, 17 insertions(+), 2 deletions(-)

diff --git a/MediaPortal/Source/Extensions/MetadataExtractors/OnlineLibraries/TheMovieDB/NamePreprocessor.cs b/MediaPortal/Source/Extensions/MetadataExtractors/OnlineLibraries/TheMovieDB/NamePreprocessor.cs
index c5a006c..21f7573 100644
--- a/MediaPortal/Source/Extensions/MetadataExtractors/OnlineLibraries/TheMovieDB/NamePreprocessor.cs
+++ b/MediaPortal/Source/Extensions/MetadataExtractors/OnlineLibraries/TheMovieDB/NamePreprocessor.cs
@@ -38,7 +38,7 @@ namespace MediaPortal.Extensions.OnlineLibraries.TheMovieDB
     public const string GROUP_YEAR = "year";
     public static readonly IList<Regex> REGEXP_TITLE_YEAR = new List<Regex>
       {
-        new Regex(@"(?<title>[^\\|\/]*)\s*\((?<year>(19|20)\d{2})\)[\.|\\|\/]*", RegexOptions.IgnoreCase), // For LocalFileSystemPath & CanonicalLocalResourcePath
+        new Regex(@"(?<title>[^\\|\/]*?)\s*[\[\(]?(?<year>(19|20)\d{2})[\]\)]?[\.|\\|\/]*", RegexOptions.IgnoreCase), // For LocalFileSystemPath & CanonicalLocalResourcePath
         // Can be extended
       };
 
@@ -53,6 +53,9 @@ namespace MediaPortal.Extensions.OnlineLibraries.TheMovieDB
         // Can be extended
       };
 
+    protected static Regex _cleanUpWhiteSpaces = new Regex(@"[\.|_](\S|$)");
+    protected static Regex _trimWhiteSpaces = new Regex(@"\s{2,}");
+
     public static bool MatchTitleYear(MovieInfo movieInfo)
     {
       foreach (Regex regex in REGEXP_TITLE_YEAR)
@@ -73,8 +76,20 @@ namespace MediaPortal.Extensions.OnlineLibraries.TheMovieDB
       string originalTitle = movieInfo.MovieName;
       foreach (Regex regex in REGEXP_CLEANUPS)
         movieInfo.MovieName = regex.Replace(movieInfo.MovieName, "");
-
+      movieInfo.MovieName = CleanupWhiteSpaces(movieInfo.MovieName);
       return originalTitle != movieInfo.MovieName;
     }
+
+    /// <summary>
+    /// Cleans up strings by replacing unwanted characters (<c>'.'</c>, <c>'_'</c>) by spaces.
+    /// </summary>
+    public static string CleanupWhiteSpaces(string str)
+    {
+      if (string.IsNullOrEmpty(str))
+        return str;
+      str = _cleanUpWhiteSpaces.Replace(str, " $1");
+      //replace multiple spaces with single space
+      return _trimWhiteSpaces.Replace(str, " ").Trim(' ', '-');
+    }
   }
 }
-- 
1.8.1.msysgit.1

